终结者2：审判日 (豆瓣)
Description: 终结者2：审判日电影简介和剧情介绍,终结者2：审判日影评、图片、预告片、影讯、论坛、在线购票
Keywords: 终结者2：审判日,Terminator 2: Judgment Day,终结者2：审判日影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.217豆瓣电影Top250

# 终结者2：审判日 Terminator 2: Judgment Day (1991)

导演: 詹姆斯·卡梅隆
编剧: 詹姆斯·卡梅隆 / 小威廉·威谢尔
主演: 阿诺·施瓦辛格 / 琳达·汉密尔顿 / 爱德华·福隆 / 罗伯特·帕特里克 / 阿尔·伯恩 / 乔·莫顿 / 埃帕莎·默克森 / 卡斯图罗·格雷拉 / 丹尼·库克塞 / 詹妮特·戈德斯坦恩 / 山德·贝克利 / 莱思莉·汉密尔顿·格伦 / 彼得·舒鲁姆 / 唐·雷克 / 吉姆·帕尔默 / 格温达·迪肯 / 科林·帕特里克·林奇 / 妮基·考克斯 / 德沃恩·尼克森 / 阿卜杜勒·萨拉姆·埃尔·拉扎克 / 迈克·马斯喀特 / 迪恩·诺里斯 / 查尔斯·A·坦伯罗 / 丹尼·皮尔斯 / 马克·克里斯托弗·劳伦斯 / 林凡 / 乔尔·克莱默 / 斯科特·肖 / 史文-欧尔·托尔森 / 小威廉·威谢尔 / Ken Gibbel / Robert Winley / Michael Edwards / Don Stanton / Dan Stanton / Lisa Brinegar / Dalton Abbott / Bret A. Arnold / Martin Deluca
类型: 动作 / 科幻
制片国家/地区: 美国 / 法国
语言: 英语 / 西班牙语
上映日期: 1991-07-03(美国) / 2017-02-17(柏林电影节 3D)
片长: 137分钟 / 153分钟(特别版) / 156分钟(终极剪辑版)
又名: 未来战士2(港) / 魔鬼终结者2(台) / 终结者2 / 终结者2：末日审判 / 终结者续集：世界末日 / T2
IMDb: tt0103064
豆瓣评分
引用
8.8
324270人评价
5星
50.0%
4星
39.4%
3星
10.1%
2星
0.5%
1星
0.1%
好于 98% 科幻片
好于 98% 动作片
想看 看过
评价:
推荐

## 终结者2：审判日的剧情简介 · · · · · ·

上一部中，超级电脑“天网”阻止人类抵抗领袖约翰·康纳诞生的行动失败，时隔13年后，在“审判日”到来之前，“天网”派出了更加先进的生化机器人T-1000（罗伯特·帕特里克 饰）从公元2029年回到洛杉矶追杀已经长大的约翰，与此同时，约翰也派出了机器人T-800（阿诺· 施瓦辛格 饰）回去保护年幼的自己。
此时，萨拉·康纳（琳达·汉密尔顿 饰）因为怪异的言行而住进了精神疗养院，约翰则和养父母住在一起，行为叛逆。T-800找到他们，在逃避T-1000追杀过程中，获得了二人的信任。
为了改变未来的历史，挽救人类的命运，萨拉、约翰和T-800 Model 101找到了“天网”之父，迈尔斯·戴森（乔·莫顿 饰），说服他销毁一切有关“天网”的资料，此时，警察和T-1000同时赶来，他们陷入了多方争斗中。 ©豆瓣

## 终结者2：审判日的演职员 · · · · · · ( 全部 79 )

- 詹姆斯·卡梅隆 导演
- 阿诺·施瓦辛格 饰 The Terminator
- 琳达·汉密尔顿 饰 Sarah Connor
- 爱德华·福隆 饰 John Connor
- 罗伯特·帕特里克 饰 T-1000
- 阿尔·伯恩 饰 Dr. Silberman

## 终结者2：审判日的视频和图片 · · · · · · ( 预告片11 | 添加视频评论 | 图片656 · 添加 )

## 终结者2：审判日的获奖情况 · · · · · · ( 全部 )

- 第64届奥斯卡金像奖
- 最佳摄影(提名)
- 亚当·格林伯格

- 第64届奥斯卡金像奖
- 最佳剪辑(提名)
- 康拉德·巴夫四世 / 马克·戈德布拉特 / 理查德·哈里斯

- 第15届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  终结者

  黑客帝国3：矩阵革命

  我，机器人

  变形金刚

  E.T.外星人

  阿凡达

  第九区

  钢铁侠

  我是传奇

  侏罗纪公园

我要写短评

## 终结者2：审判日的短评 · · · · · · ( 全部 37634 条 )

热门 / 最新 / 好友

### 1553 有用 战国客 看过 2008-06-24 22:27:48

少见的超越首部的续集，动作片中的经典~~

### 1462 有用 Dr.Moth 看过 2008-07-05 07:55:43

伙计们~还有什么比这个更棒的?

### 367 有用 唐小糖· 看过 2009-06-03 16:17:30

看这个我也能看哭，我多感性啊·

### 771 有用 Nakedself 看过 2006-05-17 16:02:10

金属狂躁！！！T1000的空前绝后在于一个机器人居然真的具有妖气。

### 53 有用 陳 看过 2009-01-05 00:13:21

小時候覺得好帥

> 更多短评 37634条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 终结者2：审判日的影评 · · · · · · ( 全部 277 条 )

热门 / 最新 / 好友
Evarnold 2007-02-23 21:40:10

## 一个T2迷对T3的反思

对于我来说，终结者系列是一种图腾。可能很多影迷和我有相同的感受。无论阿诺在其他电影中的表现有多么令我们影迷失望，我们之所以一而再、再而三地支持他，无非就一个原因：终结者、终结者、终结者！！！就因为他是终结者的缔造者之一，我们才把他作为动作电影永远的王者——... (展开)
575 44 150回应 收起
终结者T-800 2008-06-05 09:31:44

## 难以超越的科幻经典形象T-800

Ｔ－800：他原本是冷血的机器人杀手，不用杀死这个词，只用终结，在他看来那只是结束，因为不真正理解生命，所以也不真正懂得死亡，没有恐惧，没有感情，一切的一切都只是执行指令——机器的本质，但是他偏偏碰倒了并不那么理解和相信这些本质的约翰。当学习的程式启动后，... (展开)
353 16 31回应 收起
Mr.Egg 2009-07-14 23:56:22

## 无敌的T2，无敌的老卡

最近又回想起T2，个人认为卡梅隆就是“大片”这个词的最佳代言人，和他比起来斯皮尔伯格像个半路出家的天真教师，总是要在大众口味里加些温情和说教；艺术和商业上都极具实力的吕克贝松却在技术钻研上难忘其项背，更不要说法国人本来就缺少的雄浑刚健；趁着老卡不发威而崭露头... (展开)
155 14 72回应 收起
人形 2009-06-26 01:04:55

## That was what he wanted

这篇影评可能有剧透

那是一个VCD盛行的时代，曾经有位少年，他每天回家便会打开VCD机选择他心爱的影片。某天，他手里拿着一张名为Terminator 2:Judgment Day的影碟。尽管这张影碟印着一个很长的英文名字，给少年的只有陌生的感觉，但最终他还是决定将影碟的内容以图像的方式表现出来。自小就是... (展开)
81 11 13回应 收起
果子 2007-07-30 17:32:16

## 经典的T2,以及对高级AI的思考

我本来就是<Terminator>的超级Fans,昨天看了<The Sarah Connor Chronicles>,加上今天早上收到当当寄到的<智能简史>,忽然间觉得很多事情看似遥远,其实暗地里已经悄悄接近,只是我们浑然不觉. 智能机器人和人类的故事这种题材早已经不是新东西了,光电影就拍了N部. 这些故事都围绕... (展开)
60 6 15回应 收起
向容 2008-10-15 16:06:44

## 百看不厌

这是我看过遍数最多的电影，大概有二三十遍。在俺心目里，也是划时代的作品。从此成了施瓦辛格的忠实影迷。 (展开)
31 2 5回应 收起
马泽尔法克尔 2019-10-26 16:05:02

## 我和我欠的电影票

这篇影评可能有剧透

5年前庆祝生日的方式是看《大话西游》重映，这次则是看《终结者2》重映。这两部我从小到大都钟爱的时空穿越题材的电影选择在这样的日子里重映也算是给我的“献礼片”了。 首先我要重申我在五年前那篇《大话西游》的观后感里就提出的观点，我从来不认为任何观众能以任何形式欠任... (展开)
17 1 7回应 收起
柏邦妮 2009-06-03 21:54:43

## 冰山一角胜过整座冰山

因为明天要给芒果台录两期《零点锋云 影评联盟》节目， 今天专门留空看电影。 一部是《终结者2018》，一部是《袁隆平》。 在我看来，这两部电影都不是太好， 怎么说呢？ 电影塞得满满的，没有气口，没有真实感， 同时，充满了“理所当然”的设计，电影的气质也不见佳。 下午... (展开)
13 2 10回应 收起
sosovipp 2013-06-16 21:21:08

## 语录

未来尚未定数，命运并不存在，要靠自己创造。 T-1000可以模仿它摸过的物体，但仅能模仿体积相同的东西，不能变成复杂的机械。 就像我所相信的一切都是狗屎堆起来的。 “要求否决，这不是我的优先任务。” “去你的！救她是我的优先任务！” “天啊，你差点杀了那个人！” ... (展开)
13 1 1回应 收起
普通人 2005-11-30 14:26:28

## 回来还是到来——《终结者》系列

“I’ll be back。”是使《终结者》能够延续的一句经典台词，同时它更是对人类的一句警语。无论是T-800，还是T-850，甚至是更先进的T-1000和T-X。当人类的科技发展到超越自身所能掌握的高度，危机就将降临。 因此，《终结者》作为警醒世人认识到这一危机的影片——特别是它提... (展开)
16 7 6回应 收起

> 更多影评 277篇

添加新讨论

## 讨论区 · · · · · ·

从特效来讲，这个电影真是1991年左右拍摄出品的吗？ | 来自草木洁玉 | 6 回应 | 2022-11-24 09:39:23
为何我们的科幻片到今天也只有一个流浪地球 | 来自刘文师太龙 | 58 回应 | 2022-11-21 22:52:16
T1000长的很像。。。。 | 来自Teukie | 20 回应 | 2022-11-21 18:34:24
为什么第二部评分这么高？ | 来自伊芙&瓦力 | 15 回应 | 2022-11-08 11:57:41
那个黑人演技也太好了吧 | 来自末本 |  | 2022-11-01 19:18:44

> 去这部影片的讨论区（全部140条）

## 关于《终结者2：审判日》的问题 · · · · · · ( 全部14个 )

- 所以终结者和天网到底是谁发明的？ 4人回答
- 能不能不看第一部直接看2呢？ 7人回答

> 全部14个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- {北美电影票房总排行} (荔枝超人)
- 电影中的美少年 (海棠一生)

## 谁在看这部电影 · · · · · ·

- 豆友O4WfE_FJiI
  4分钟前 看过
- z
  25分钟前 看过
- 一不小心的出现
  36分钟前 看过

545925人看过 / 76536人想看

订阅终结者2：审判日的评论:
feed: rss 2.0